summaryrefslogtreecommitdiff
path: root/install.sh
diff options
context:
space:
mode:
authorFahim2015-09-04 17:44:27 +0530
committerFahim2015-09-04 17:44:27 +0530
commitefb29dd4732f93c1b6a87e90909dcb576640e3bc (patch)
treec9cef13ce556c912241c45e8e90ee63318631b50 /install.sh
parent267049a90c91aaabb11182f2748760d60b21882f (diff)
downloadnghdl-efb29dd4732f93c1b6a87e90909dcb576640e3bc.tar.gz
nghdl-efb29dd4732f93c1b6a87e90909dcb576640e3bc.tar.bz2
nghdl-efb29dd4732f93c1b6a87e90909dcb576640e3bc.zip
Subject: Added Appconfig.py. And changed .FreeEDA to .esim-nghdl
Description: Added Appconfig.py. And changed .FreeEDA to .esim-nghdl
Diffstat (limited to 'install.sh')
-rwxr-xr-xinstall.sh6
1 files changed, 3 insertions, 3 deletions
diff --git a/install.sh b/install.sh
index 9cadbb0..0aec668 100755
--- a/install.sh
+++ b/install.sh
@@ -12,13 +12,13 @@
# BUGS: ---
# NOTES: ---
# AUTHOR: Fahim Khan , fahim.elex@gmail.com
# ORGANIZATION: FreeEDA, FOSSEE group at IIT Bombay
# CREATED: Tuesday 02 December 2014 17:01
# REVISION: ---
#===============================================================================
ngspice="ngspice-26"
-src_loc=".FreeEDA"
+src_loc=".esim-nghdl"
config_file="config.ini"
cur_dir=`pwd`
@@ -141,7 +141,7 @@ fi
#Creating directory to put source
if [ -d "$HOME/$src_loc" ];then
- echo "(.)FreeEDA directory already in $HOME,removing it and copying new code"
+ echo "(.)esim-nghdl directory already in $HOME,removing it and copying new code"
rm -rf ~/$src_loc
mkdir -p ~/$src_loc
else
@@ -12,13 +12,13 @@
# NOTES: ---
# AUTHOR: Fahim Khan , fahim.elex@gmail.com
-# ORGANIZATION: FreeEDA, FOSSEE group at IIT Bombay
+# ORGANIZATION: eSim, FOSSEE group at IIT Bombay
# CREATED: Tuesday 02 December 2014 17:01
# REVISION: ---